=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2011-06-01 08:22:24 +0000
+++ bzrlib/builtins.py	2011-06-01 12:53:56 +0000
@@ -234,7 +234,7 @@
     Additionally for directories, symlinks and files with a changed
     executable bit, Bazaar indicates their type using a trailing
     character: '/', '@' or '*' respectively. These decorations can be
-    disabled using the '--no-decorate' option.
+    disabled using the '--no-classify' option.
 
     To see ignored files use 'bzr ignored'.  For details on the
     changes to file texts, use 'bzr diff'.
@@ -271,8 +271,8 @@
                             short_name='V'),
                      Option('no-pending', help='Don\'t show pending merges.',
                            ),
-                     Option('no-decorate',
-                            help='Do not mark object type.',
+                     Option('no-classify',
+                            help='Do not mark object type using indicator.',
                            ),
                      ]
     aliases = ['st', 'stat']
@@ -283,7 +283,7 @@
     @display_command
     def run(self, show_ids=False, file_list=None, revision=None, short=False,
             versioned=False, no_pending=False, verbose=False,
-            no_decorate=False):
+            no_classify=False):
         from bzrlib.status import show_tree_status
 
         if revision and len(revision) > 2:
@@ -304,7 +304,7 @@
                          specific_files=relfile_list, revision=revision,
                          to_file=self.outf, short=short, versioned=versioned,
                          show_pending=(not no_pending), verbose=verbose,
-                         no_decorate=no_decorate)
+                         classify=not no_classify)
 
 
 class cmd_cat_revision(Command):

=== modified file 'bzrlib/delta.py'
--- bzrlib/delta.py	2011-06-01 08:22:24 +0000
+++ bzrlib/delta.py	2011-06-01 12:53:56 +0000
@@ -175,7 +175,7 @@
 
     def __init__(self, output=None, suppress_root_add=True,
                  output_file=None, unversioned_filter=None, view_info=None,
-                 kind_marker=None):
+                 classify=True):
         """Constructor
 
         :param output: a function with the signature of trace.note, i.e.
@@ -190,8 +190,7 @@
         :param view_info: A tuple of view_name,view_files if only
             items inside a view are to be reported on, or None for
             no view filtering.
-        :param kind_marker: Function to get kind decoration symbols,
-            None for default, or False to disable decorations.
+        :param classify: Add special symbols to indicate file kind.
         """
         if output_file is not None:
             if output is not None:
@@ -216,10 +215,10 @@
                               'unversioned': '?', # versioned in neither
                               }
         self.unversioned_filter = unversioned_filter
-        if kind_marker is False:
-            def kind_marker(kind):
-                return ''
-        self.kind_marker = kind_marker or osutils.kind_marker
+        if classify:
+            self.kind_marker = osutils.kind_marker
+        else:
+            self.kind_marker = lambda kind: ''
         if view_info is None:
             self.view_name = None
             self.view_files = []
@@ -347,7 +346,7 @@
                         exe_change, kind)
 
 def report_delta(to_file, delta, short_status=False, show_ids=False, 
-         show_unchanged=False, indent='', filter=None, no_decorate=False):
+         show_unchanged=False, indent='', filter=None, classify=True):
     """Output this delta in status-like form to to_file.
 
     :param to_file: A file-like object where the output is displayed.
@@ -366,12 +365,11 @@
     :param filter: A callable receiving a path and a file id and
         returning True if the path should be displayed.
 
-    :param no_decorate: Do not add special symbols for symlinks or
-        modified metadata.
+    :param classify: Add special symbols to indicate file kind.
     """
 
     def decorate_path(path, kind, meta_modified=None):
-        if no_decorate:
+        if not classify:
             return path
         if kind == 'directory':
             path += '/'

=== modified file 'bzrlib/status.py'
--- bzrlib/status.py	2011-06-01 08:22:24 +0000
+++ bzrlib/status.py	2011-06-01 12:53:56 +0000
@@ -34,7 +34,7 @@
 def report_changes(to_file, old, new, specific_files, 
                    show_short_reporter, show_long_callback, 
                    short=False, want_unchanged=False, 
-                   want_unversioned=False, show_ids=False, no_decorate=False):
+                   want_unversioned=False, show_ids=False, classify=True):
     """Display summary of changes.
 
     This compares two trees with regards to a list of files, and delegates 
@@ -59,8 +59,7 @@
         files.
     :param show_ids: If set, includes each file's id.
     :param want_unversioned: If False, only shows versioned files.
-    :param no_decorate: Do not add special symbols for symlinks or
-        modified metadata.
+    :param classify: Add special symbols to indicate file kind.
     """
 
     if short:
@@ -79,7 +78,7 @@
         show_long_callback(to_file, delta, 
                            show_ids=show_ids,
                            show_unchanged=want_unchanged,
-                           no_decorate=no_decorate)
+                           classify=classify)
 
 
 def show_tree_status(wt, show_unchanged=None,
@@ -91,7 +90,7 @@
                      short=False,
                      verbose=False,
                      versioned=False,
-                     no_decorate=False,
+                     classify=True,
                      show_long_callback=_mod_delta.report_delta):
     """Display summary of changes.
 
@@ -121,8 +120,7 @@
     :param verbose: If True, show all merged revisions, not just
         the merge tips
     :param versioned: If True, only shows versioned files.
-    :param no_decorate: Do not add special symbols for symlinks or
-        modified metadata.
+    :param classify: Add special symbols to indicate file kind.
     :param show_long_callback: A callback: message = show_long_callback(to_file, delta, 
         show_ids, show_unchanged, indent, filter), only used with the long output
     """
@@ -166,16 +164,13 @@
             want_unversioned = not versioned
 
             # Reporter used for short outputs
-            kind_marker = None
-            if no_decorate:
-                kind_marker = False
             reporter = _mod_delta._ChangeReporter(output_file=to_file,
-                unversioned_filter=new.is_ignored, kind_marker=kind_marker)
+                unversioned_filter=new.is_ignored, classify=classify)
             report_changes(to_file, old, new, specific_files, 
                            reporter, show_long_callback, 
                            short=short, want_unchanged=show_unchanged, 
                            want_unversioned=want_unversioned, show_ids=show_ids,
-                           no_decorate=no_decorate)
+                           classify=classify)
 
             # show the ignored files among specific files (i.e. show the files
             # identified from input that we choose to ignore). 

